Package: shinyMixR
Title: Interactive 'shiny' Dashboard for 'nlmixr2'
Version: 0.5.3
Authors@R: c(person("Richard", "Hooijmaijers", email = "richardhooijmaijers@gmail.com", role = c("aut", "cre","cph")),
             person("Teun", "Post", email = "teunpost@gmail.com",role = c("aut","cph")),
             person("LAPP Consultants",email = "info@lapp.nl", role=c("fnd","cph")),
             person("Matthew Fidler",role=c("ctb")),
             person("Veerle van Leemput",role=c("ctb")))
Description: An R shiny user interface for the 'nlmixr2' (Fidler et al (2019) <doi:10.1002/psp4.12445>) package,
  designed to simplify the modeling process for users. Additionally, this package includes supplementary functions
  to further enhances the usage of 'nlmixr2'.
Depends: R (>= 3.5.0), shiny, ggplot2
Imports: gridExtra, collapsibleTree, shinyAce, DT, bs4Dash,
        shinyWidgets, stringi, R3port, whisker, plotly, patchwork,
        shinyjs, ps, xfun, fresh, nlmixr2est (>= 5.0.0), magrittr,
        rxode2 (>= 5.0.0), cli
Suggests: xpose, nlmixr2, nlmixr2plot, xpose.nlmixr2, nlme, testthat,
        shinytest2, knitr, rmarkdown, rlang, miniUI, shinyFiles,
        rstudioapi
License: MIT + file LICENSE
URL: https://github.com/RichardHooijmaijers/shinyMixR/,
        https://richardhooijmaijers.github.io/shinyMixR/
BugReports: https://github.com/RichardHooijmaijers/shinyMixR/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-12-03 10:43:53 UTC; r.hooijmaijers
Author: Richard Hooijmaijers [aut, cre, cph],
  Teun Post [aut, cph],
  LAPP Consultants [fnd, cph],
  Matthew Fidler [ctb],
  Veerle van Leemput [ctb]
Maintainer: Richard Hooijmaijers <richardhooijmaijers@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-03 11:00:02 UTC
Built: R 4.6.0; ; 2026-04-30 21:37:07 UTC; unix
