# shinyMixR: Shiny dashboard interface for nlmixr

<!-- badges: start -->
[![R-CMD-check](https://github.com/richardhooijmaijers/shinyMixR/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/richardhooijmaijers/shinyMixR/actions/workflows/R-CMD-check.yaml)
[![Codecov test coverage](https://codecov.io/gh/richardhooijmaijers/shinyMixR/branch/master/graph/badge.svg)](https://app.codecov.io/gh/richardhooijmaijers/shinyMixR?branch=master)
<!-- badges: end -->

The shinyMixR package is initially developed as a graphical interface for the `nlmixr` package and provides full support for `nlmixr2`.
The package include a shiny (dashboard) interface and helps in managing, running, editing and analysing nlmixr models.
Although the main focus was to build an interface, many of the package functions are also directly available for usage in an interactive R session.

## Installation

Currently the package is under active development and can be installed using:

```R
devtools::install_github("richardhooijmaijers/shinyMixR")
```

## Documentation

A short introduction to the package can be found in the article section on the [packagedown site](https://richardhooijmaijers.github.io/shinyMixR/index.html)
It is advised for existing users to read `news.md` to see all the latest changes to the package.

## License

[MIT license](http://opensource.org/licenses/MIT)
